@@ -153,6 +153,59 @@ function _add_edit_url(filename, url)
     return
 end
 
+# ==============================================================================
+#  Add tutorial overview
+# ==============================================================================
+
+package_to_headers = Dict{String,Vector{String}}()
+
+for (root, dirs, files) in walkdir(joinpath(@__DIR__, "src", "tutorials"))
+    for file in filter(f -> endswith(f, ".jl") | endswith(f, ".md"), files)
+        contents = read(joinpath(root, file), String)
+        if startswith(contents, "```@meta")
+            continue  # Already literated
+        end
+        m = match(r"\n# # (.+)\n", contents)
+        if m === nothing
+            m = match(r"^# (.+)\n", contents)
+        end
+        title = m[1]
+        anchor = "[$title](@ref)"
+        if occursin("@id", title)
+            m = match(r"\[(.+)\]\(@id (.+)\)", title)
+            anchor = "[$(m[1])](@ref $(m[2]))"
+        end
+        import_regex = r"\nimport ([a-z][A-Z]+)( as [a-zA-Z]+)?\n"i
+        for m in eachmatch(import_regex, contents; overlap = true)
+            push!(get!(package_to_headers, m[1], String[]), anchor)
+        end
+    end
+end
+
+open(joinpath(@__DIR__, "src", "tutorials", "overview.md"), "w") do io
+    println(
+        io,
+        """
+        # Tutorials by package
+
+        To make it easier to find relevant tutorials, this page lists all the tutorials
+        by the packages they import.
+
+        For example, to find tutorials that solve nonlinear programs, look at the
+        [Ipopt.jl](@ref tutorial_Ipopt) section.
+        """,
+    )
+    for (pkg, tutorials) in sort!(collect(package_to_headers))
+        if pkg == "JuMP"
+            continue
+        end
+        println(io, "## [$(pkg).jl](@id tutorial_$pkg)")
+        println(io, join(unique(sort!(tutorials)), " • "))
+        println(io)
+    end
+    return
+end
+
 # ==============================================================================
 #  Add solver README
 # ==============================================================================
@@ -335,6 +388,7 @@ jump_api_reference = DocumenterReference.automatic_reference_documentation(;
 const _PAGES = [
     "Introduction" => ["index.md", "should_i_use.md", "installation.md"],
     "Tutorials" => [
+        "tutorials/overview.md",
         "Getting started" => [
             "tutorials/getting_started/introduction.md",
             "tutorials/getting_started/getting_started_with_julia.md",
@@ -365,8 +419,9 @@ const _PAGES = [
             "tutorials/linear/geographic_clustering.md",
             "tutorials/linear/network_flows.md",
             "tutorials/linear/transp.md",
-            "tutorials/linear/multi_objective_knapsack.md",
             "tutorials/linear/multi_objective_examples.md",
+            "tutorials/linear/multi_objective_knapsack.md",
+            "tutorials/linear/multi_objective_project_planning.md",
             "tutorials/linear/sudoku.md",
             "tutorials/linear/n-queens.md",
             "tutorials/linear/constraint_programming.md",
@@ -389,6 +444,7 @@ const _PAGES = [
             "tutorials/nonlinear/portfolio.md",
             "tutorials/nonlinear/rocket_control.md",
             "tutorials/nonlinear/space_shuttle_reentry_trajectory.md",
+            "tutorials/nonlinear/vector_nonlinear_oracle.md",
         ],
         "Conic programs" => [
             "tutorials/conic/introduction.md",
@@ -559,17 +615,24 @@ function _add_moi_pages()
             end
         end
     end
-    # Fix `# Infeasibility certificates` in moi/background/infeasibility_certificates.md
-    filename = joinpath(moi_dir, "background", "infeasibility_certificates.md")
-    contents = read(filename, String)
-    id = "# [Infeasibility certificates](@id moi_infeasibility_certificates)"
-    contents = replace(contents, r"^# Infeasibility certificates$"m => id)
-    write(filename, contents)
-    # Fix `JSON.Object` in moi/submodules/FileFormats/overview.md
-    # This can be removed once we support JSON@1 in the documentation
-    filename = joinpath(moi_dir, "submodules", "FileFormats", "overview.md")
-    contents = read(filename, String)
-    write(filename, replace(contents, "JSON.Object" => "Dict"))
+    for (filename, replacements) in [
+        "background/infeasibility_certificates.md" => [
+            r"^# Infeasibility certificates$"m => "# [Infeasibility certificates](@id moi_infeasibility_certificates)",
+        ],
+        "reference/models.md" => ["# ResultStatusCode" => "# Result Status"],
+        # This can be removed once we support JSON@1 in the documentation
+        "submodules/FileFormats/overview.md" => ["JSON.Object" => "Dict"],
+        # These can be removed once we support MOI@1.48.1 or later
+        "reference/models.md" => ["# ResultStatusCode" => "# Result Status"],
+        "submodules/Nonlinear/SymbolicAD.md" => [
+            "# `simplify`" => "# [`simplify`](@id symbolic_ad_manual_simplify)",
+            "# `variables`" => "# [`variables`](@id symbolic_ad_manual_variables)",
+            "# `derivative`" => "# [`derivative`](@id symbolic_ad_manual_derivative)",
+        ],
+    ]
+        filename = joinpath(moi_dir, filename)
+        write(filename, replace(read(filename, String), replacements...))
+    end
     return
 end
 
