@@ -21,7 +21,7 @@ julia> op_ifelse(true, 1.0, 2.0)
 1.0
 
 julia> op_ifelse(x, 1.0, 2.0)
-ifelse(x, 1.0, 2.0)
+ifelse(x, 1, 2)
 
 julia> op_ifelse(true, x, 2.0)
 x
